.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Project Operations

   versioning
   changelog

***
API
***

.. toctree::
   :maxdepth: 2
   :caption: Public API

   lib/api/index

.. _AWS Step Functions: https://docs.aws.amazon.com/step-functions/latest/dg/welcome.html
.. _AWS CloudFormation: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/Welcome.html
.. _Troposphere: https://troposphere.readthedocs.io
